@@ -2,5 +2,5 @@ from .pose import Pose
 from .transform_set import TransformSet
 from .transform import Transform
 
-from .te import TE
-from .re import RE
\ No newline at end of file
+from .et import ET
+from .er import ER
\ No newline at end of file
